==> CGAL-5.6.1-doc_html.tar.xz: doc_html/Triangulation_3/examples.js <==
var examples =
[
    [ "Triangulation_3/adding_handles_3.cpp", "Triangulation_3_2adding_handles_3_8cpp-example.html", null ],
    [ "Triangulation_3/color.cpp", "Triangulation_3_2color_8cpp-example.html", null ],
    [ "Triangulation_3/copy_triangulation_3.cpp", "Triangulation_3_2copy_triangulation_3_8cpp-example.html", null ],
    [ "Triangulation_3/draw_triangulation_3.cpp", "Triangulation_3_2draw_triangulation_3_8cpp-example.html", null ],
    [ "Triangulation_3/fast_location_3.cpp", "Triangulation_3_2fast_location_3_8cpp-example.html", null ],
    [ "Triangulation_3/find_conflicts_3.cpp", "Triangulation_3_2find_conflicts_3_8cpp-example.html", null ],
    [ "Triangulation_3/for_loop.cpp", "Triangulation_3_2for_loop_8cpp-example.html", null ],
    [ "Triangulation_3/info_insert_with_pair_iterator.cpp", "Triangulation_3_2info_insert_with_pair_iterator_8cpp-example.html", null ],
    [ "Triangulation_3/info_insert_with_transform_iterator.cpp", "Triangulation_3_2info_insert_with_transform_iterator_8cpp-example.html", null ],
    [ "Triangulation_3/info_insert_with_zip_iterator.cpp", "Triangulation_3_2info_insert_with_zip_iterator_8cpp-example.html", null ],
    [ "Triangulation_3/parallel_insertion_and_removal_in_regular_3.cpp", "Triangulation_3_2parallel_insertion_and_removal_in_regular_3_8cpp-example.html", null ],
    [ "Triangulation_3/parallel_insertion_in_delaunay_3.cpp", "Triangulation_3_2parallel_insertion_in_delaunay_3_8cpp-example.html", null ],
    [ "Triangulation_3/regular_3.cpp", "Triangulation_3_2regular_3_8cpp-example.html", null ],
    [ "Triangulation_3/regular_with_info_3.cpp", "Triangulation_3_2regular_with_info_3_8cpp-example.html", null ],
    [ "Triangulation_3/segment_cell_traverser_3.cpp", "Triangulation_3_2segment_cell_traverser_3_8cpp-example.html", null ],
    [ "Triangulation_3/segment_simplex_traverser_3.cpp", "Triangulation_3_2segment_simplex_traverser_3_8cpp-example.html", null ],
    [ "Triangulation_3/simple_triangulation_3.cpp", "Triangulation_3_2simple_triangulation_3_8cpp-example.html", null ],
    [ "Triangulation_3/simplex.cpp", "Triangulation_3_2simplex_8cpp-example.html", null ]
];

==> CGAL-6.0.1-doc_html.tar.xz: doc_html/Triangulation_3/examples.js <==
var examples =
[
    [ "Triangulation_3/simple_triangulation_3.cpp", "Triangulation_3_2simple_triangulation_3_8cpp-example.html", null ],
    [ "Triangulation_3/for_loop.cpp", "Triangulation_3_2for_loop_8cpp-example.html", null ],
    [ "Triangulation_3/color.cpp", "Triangulation_3_2color_8cpp-example.html", null ],
    [ "Triangulation_3/adding_handles_3.cpp", "Triangulation_3_2adding_handles_3_8cpp-example.html", null ],
    [ "Triangulation_3/info_insert_with_pair_iterator.cpp", "Triangulation_3_2info_insert_with_pair_iterator_8cpp-example.html", null ],
    [ "Triangulation_3/info_insert_with_zip_iterator.cpp", "Triangulation_3_2info_insert_with_zip_iterator_8cpp-example.html", null ],
    [ "Triangulation_3/info_insert_with_transform_iterator.cpp", "Triangulation_3_2info_insert_with_transform_iterator_8cpp-example.html", null ],
    [ "Triangulation_3/simplex.cpp", "Triangulation_3_2simplex_8cpp-example.html", null ],
    [ "Triangulation_3/fast_location_3.cpp", "Triangulation_3_2fast_location_3_8cpp-example.html", null ],
    [ "Triangulation_3/segment_cell_traverser_3.cpp", "Triangulation_3_2segment_cell_traverser_3_8cpp-example.html", null ],
    [ "Triangulation_3/segment_simplex_traverser_3.cpp", "Triangulation_3_2segment_simplex_traverser_3_8cpp-example.html", null ],
    [ "Triangulation_3/find_conflicts_3.cpp", "Triangulation_3_2find_conflicts_3_8cpp-example.html", null ],
    [ "Triangulation_3/regular_3.cpp", "Triangulation_3_2regular_3_8cpp-example.html", null ],
    [ "Triangulation_3/regular_with_info_3.cpp", "Triangulation_3_2regular_with_info_3_8cpp-example.html", null ],
    [ "Triangulation_3/copy_triangulation_3.cpp", "Triangulation_3_2copy_triangulation_3_8cpp-example.html", null ],
    [ "Triangulation_3/parallel_insertion_in_delaunay_3.cpp", "Triangulation_3_2parallel_insertion_in_delaunay_3_8cpp-example.html", null ],
    [ "Triangulation_3/parallel_insertion_and_removal_in_regular_3.cpp", "Triangulation_3_2parallel_insertion_and_removal_in_regular_3_8cpp-example.html", null ],
    [ "Triangulation_3/draw_triangulation_3.cpp", "Triangulation_3_2draw_triangulation_3_8cpp-example.html", null ]
];
